@@ -4,6 +4,7 @@ The default group of operations that pyflexebs has
 import logging
 import os
 import time
+from pprint import pprint
 
 import boto3
 import ec2_metadata
@@ -155,8 +156,9 @@ def show_policies() -> None:
     session = boto3.session.Session(region_name=metadata.region)
     iam = session.client('iam')
     policy_list = iam.list_attached_role_policies(RoleName=name)
-    for policy in policy_list.AttachedPolicies:
-        print(policy)
+    pprint(policy_list)
+    # for policy in policy_list.AttachedPolicies:
+    #    print(policy)
 
 
 def configure_proxy():
